@@ -59,6 +59,7 @@ class kernel(_error):
         class KernelConfig:
             def __init__(self):
                 self.body = OrderedDict()
+                self.remove = []
 
         doc = KernelConfig()
         for line in (x for x in self.text.split('\n')
@@ -70,9 +71,9 @@ class kernel(_error):
             else:
                 key, op, value = line.strip().partition('=')
             if key[:1] == '!':
-                key = key[1:]
-                value = 'n'
-            doc.body[key] = value
+                doc.remove.append(key[1:])
+            else:
+                doc.body[key] = value
         return doc
 
     def join(self, xml_xfceObj):
@@ -92,6 +93,8 @@ class kernel(_error):
     def _join(self, xmlNewNode, xmlOldNode):
         """Объединение корневой ноды шаблона и корневой ноды файла"""
         xmlOldNode.body.update(xmlNewNode.body)
+        for opt in xmlNewNode.remove:
+            xmlOldNode.body.pop(opt, None)
         return True
 
     def joinDoc(self, doc):
