@@ -43,6 +43,17 @@ class samba(objShare):
 
     def postXML(self):
         """Последующая постобработка XML"""
+        # удаляем пустые области
+        xmlAreas = xpath.Evaluate("child::area", self.docObj.body)
+        removeList = []
+        for xmlArea in xmlAreas:
+            xmlFields = xpath.Evaluate("child::field/name", xmlArea)
+            if not xmlFields:
+                removeList.append(xmlArea)
+        for xmlArea in removeList:
+            parentNode = xmlArea.parentNode
+            parentNode.removeChild(xmlArea)
+
         # Для добавления перевода строки между областями если его нет
         xmlAreas = xpath.Evaluate("child::area", self.docObj.body)
         xmlArea = None
